@@ -3,5 +3,5 @@
 #
 GDK_PIXBUF_LIBDIR="-L/usr/X11R6/lib "
 GDK_PIXBUF_LIBS="-L/usr/local/lib -lgmodule12 -lglib12 -ldl -lgdk_pixbuf -L/usr/X11R6/lib -L/usr/X11R6/lib -lgtk12 -lgdk12 -L/usr/local/lib -lgmodule12 -lglib12 -ldl -lintl -lxpg4 -lXext -lX11 -lm "
-GDK_PIXBUF_INCLUDEDIR="-I/usr/X11R6/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include "
-MODULE_VERSION="gdk-pixbuf-0.11.0"
+GDK_PIXBUF_INCLUDEDIR="-I/usr/X11R6/include/gdk-pixbuf-1.0 -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include "
+MODULE_VERSION="gdk-pixbuf-0.13.0"
